==> haskell-reducers-3.12.3-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.3
id: reducers-3.12.3-1VvH19kmQ7HNgbffCa80m
key: reducers-3.12.3-1VvH19kmQ7HNgbffCa80m
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework.
category: Data, Math, Numerical, Semigroups
abi: 228227fa79b84fd4980bb12550f3adb9
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
import-dirs: /usr/lib/ghc-8.4.3/site-local/reducers-3.12.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/reducers-3.12.3
hs-libraries: HSreducers-3.12.3-1VvH19kmQ7HNgbffCa80m
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    fingertree-0.1.4.1-6KXQXAC5X7vHYpS4NMyKvJ
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    semigroupoids-5.3.1-5yqExbNHNs5HvmpD7pxLfb text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             fingertree-0.1.4.1-6KXQXAC5X7vHYpS4NMyKvJ=153938428f0e1192a451c7f154ce370e
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             semigroupoids-5.3.1-5yqExbNHNs5HvmpD7pxLfb=1e26706ac3e6c4ab8467a720a672b919
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.3-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.3
id: reducers-3.12.3-2zmd5ZoDTNzG1DxV5l3xdl
key: reducers-3.12.3-2zmd5ZoDTNzG1DxV5l3xdl
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework.
category: Data, Math, Numerical, Semigroups
abi: 23c382851aa43a533a5c35b63b46cf2e
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
import-dirs: /usr/lib/ghc-8.6.3/site-local/reducers-3.12.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/reducers-3.12.3
hs-libraries: HSreducers-3.12.3-2zmd5ZoDTNzG1DxV5l3xdl
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    fingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.1-3v7umH7l71x7sUYBS0aazs text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
